@@ -5,7 +5,7 @@ use vars qw( $VERSION @EXPORT %CONF );
 use base qw( Exporter );
 use Config::General ();
 
-$VERSION = '0.7900';
+$VERSION = '0.7901';
 @EXPORT  = qw( %CONF );
 
 %CONF = Config::General::ParseConfig( -String => <<'RAW' );
@@ -154,9 +154,11 @@ $VERSION = '0.7900';
 </redflag>
 
 <redhat>
-    version_match = Red Hat Linux release (.*) \(
+    manufacturer  = Red Hat, Inc.
+    version_match = Red Hat (?:Enterprise )?Linux (?:Server )release (.*) \(
     release = redhat-release
     release = redhat_version
+    use_codename_for_edition = 1
 </redhat>
 
 <pardus>
@@ -240,8 +242,8 @@ Sys::Info::Driver::Linux::OS::Distribution::Conf - Distro configuration
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7900> of C<Sys::Info::Driver::Linux::OS::Distribution::Conf>
-released on C<5 January 2012>.
+This document describes version C<0.7901> of C<Sys::Info::Driver::Linux::OS::Distribution::Conf>
+released on C<16 July 2012>.
 
 =head1 AUTHOR
 
@@ -253,8 +255,7 @@ Copyright 2006 - 2012 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.4 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.14.2 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
